pm4py.algo.conformance.alignments.petri\_net.variants package
=============================================================

Submodules
----------

pm4py.algo.conformance.alignments.petri\_net.variants.dijkstra\_less\_memory module
-----------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.variants.dijkstra_less_memory
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.petri\_net.variants.dijkstra\_no\_heuristics module
-------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.variants.dijkstra_no_heuristics
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.petri\_net.variants.discounted\_a\_star module
--------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.variants.discounted_a_star
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.petri\_net.variants.state\_equation\_a\_star module
-------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.variants.state_equation_a_star
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.petri\_net.variants.tweaked\_state\_equation\_a\_star module
----------------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.variants.tweaked_state_equation_a_star
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.variants
   :members:
   :undoc-members:
   :show-inheritance:
